library(testthat)
library(embed)

test_check("embed")
